/*
 * Copyright (c) 2016-2020 ARM Limited. All rights reserved.
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Licensed under the Apache License, Version 2.0 (the License); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * -----------------------------------------------------------------------------
 *
 * $Revision:   V1.0.2
 *
 * Project:     CM0 RTOS Timer
 * Title:       main.c
 *
 * -----------------------------------------------------------------------------
 */

#include "RTE_Components.h"             // Component selection
#include CMSIS_device_header

#include "EventRecorder.h"              // Keil::Compiler:Event Recorder

#include "cmsis_os2.h"                  // ARM::CMSIS:RTOS2:Keil RTX5


/*----------------------------------------------------------------------------
 * Sample timer functions
 *---------------------------------------------------------------------------*/

/*----- One-Shoot Timer Example -----*/
static void Timer1_Callback (void const *arg);                  // prototype for timer callback function

osTimerId_t tim_id1;                                            // timer id
static uint32_t  exec1;                                         // argument for the timer call back function

// One-Shoot Timer Function
static void Timer1_Callback (void const *arg) {
  // add user code here
}

/*----- Periodic Timer Example -----*/
static void Timer2_Callback (void const *arg);                  // prototype for timer callback function

osTimerId_t tim_id2;                                            // timer id
static uint32_t  exec2;                                         // argument for the timer call back function

// Periodic Timer Example
static void Timer2_Callback (void const *arg) {
  // add user code here
}

// Example: Create and Start timers
int Init_Timers (void) {
  osStatus_t status;                                            // function return status

  // Create one-shoot timer
  exec1 = 1;
  tim_id1 = osTimerNew ((osTimerFunc_t)&Timer1_Callback, osTimerOnce, &exec1, NULL);
  if (tim_id1 != NULL) {    // One-shot timer created
    // start timer with delay 100ms
    status = osTimerStart (tim_id1, 100);
    if (status != osOK) {
      return -1;
    }
  }

  // Create periodic timer
  exec2 = 2;
  tim_id2 = osTimerNew((osTimerFunc_t)&Timer2_Callback, osTimerPeriodic, &exec2, NULL);
  if (tim_id2 != NULL) {    // Periodic timer created
    // start timer with periodic 1000ms interval
    status = osTimerStart (tim_id2, 1000);
    if (status != osOK) {
      return -1;
    }
  }

  return NULL;
}

/*----------------------------------------------------------------------------
 * Application main thread
 *---------------------------------------------------------------------------*/
void app_main (void *argument) {

  (void)argument;

	Init_Timers ();                       // Initalize User Timers

  for (;;) {
		osDelay (100);
	}
}


/*----------------------------------------------------------------------------
 * Main thread
 *---------------------------------------------------------------------------*/
int main (void) {

  SystemCoreClockUpdate();

  osKernelInitialize();                 // Initialize CMSIS-RTOS

  osThreadNew(app_main, NULL, NULL);    // Create application main thread

  osKernelStart();                      // Start thread execution
}
