/*
 * Copyright (c) 2016-2020 ARM Limited. All rights reserved.
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Licensed under the Apache License, Version 2.0 (the License); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * -----------------------------------------------------------------------------
 *
 * $Revision:   V1.0.2
 *
 * Project:     MyComponent
 * Title:       main.c
 *
 * -----------------------------------------------------------------------------
 */

#include "RTE_Components.h"             // Component selection
#include CMSIS_device_header

#include "EventRecorder.h"              // Keil::Compiler:Event Recorder
#include "MyComponent.h"

#include "cmsis_os2.h"                  // ARM::CMSIS:RTOS2:Keil RTX5


extern const osThreadAttr_t app_attr;

static uint32_t some_error = 0;
static char string[10] = "MyTest";

static             void MyFunction (uint32_t);
static __NO_RETURN void app_main (void *);

void MyFunction (uint32_t parameter) {
  EventRecord2 (1+EventLevelAPI, parameter, 0);              // Event at Start
  // some code that modifies 'some_error'
  if (some_error)  {
    EventRecord2 (2+EventLevelError, 0, 0);                  // Event at Error
    return;
  }

  EventRecordData (3+EventLevelOp, string, sizeof(string));  // Event at Finish

  return;
}

const osThreadAttr_t app_attr = {
  .stack_size = 2048
};

/*----------------------------------------------------------------------------
 * Application main thread
 *---------------------------------------------------------------------------*/
void app_main (void *argument) {
  int n = 0;

  (void)argument;

  while(1) {
  	MyComp_send("Test");                        // send test message -> will succeed
  	MyComp_send("Test");                        // immediate resend  -> will fail
  	osDelay(1000);                              // delay to be able to receive test message

  	{
      char buf[256];
      MyComp_receive(buf);                      // receive message   -> will succeed
      MyComp_receive(buf);                      // immediate call to receive -> will fail
    }
	  MyFunction (0x60);
  	osDelay(1000);

    if (n & 1)  {
      EventRecord2 (0x8000, 1, 2);
      EventRecord2 (0x8001, 3, 4);
      EventRecord2 (0x8002, 5, 6);
      EventRecord2 (0x8003, 7, 8);
    }
    else  {
      EventRecord2 (0x8B00, 1, 2);
      EventRecord2 (0x8B01, 3, 4);
      EventRecord2 (0x8B02, 5, 6);
      EventRecord2 (0x8B03, 7, 8);
    }
    ++n;

  	osDelay (100);
  }
}


int main (void) {

  SystemCoreClockUpdate();

  osKernelInitialize();                         // initialize CMSIS-RTOS

  MyFunction (0x10);
	some_error = 1;
	MyFunction (0x60);
	some_error = 0;

  EventRecord2 (0x8B00, 1, 2);
  EventRecord2 (0x8B01, 3, 4);
  EventRecord2 (0x8B02, 5, 6);
  EventRecord2 (0x8B03, 7, 8);

  MyComp_initialize();                          // initialize MyComponent

  osThreadNew(app_main, NULL, &app_attr);

  osKernelStart ();
}
