/*
 * Copyright (c) 2016-2020 ARM Limited. All rights reserved.
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Licensed under the Apache License, Version 2.0 (the License); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * -----------------------------------------------------------------------------
 *
 * $Revision:   V1.0.2
 *
 * Project:     MyComponent
 * Title:       MyComponent.c
 *
 * -----------------------------------------------------------------------------
 */

#include <stdint.h>
#include <stdio.h>
#include <string.h>

#define MyComp_DEBUG                               // enable debug events

#include "MyComponent.h"

struct MyComp_info_t MyComp_info;
struct MyComp_data_t MyComp_data;

// Initialize
void MyComp_initialize (void) {
  EvrMyCo_InitEntry();                             // Record Event
  MyComp_info.version = 3;                         // Set information
  MyComp_info.channels = 1;
  MyComp_info.buffersize = sizeof(MyComp_data.buf);
  memset (&MyComp_data, 0, sizeof(MyComp_data));   // Zero initialize
  MyComp_data.is_free = 1;
  EvrMyCo_InitStatus(1);                           // Record Event
}

// Send message to buffer
void MyComp_send (char* str) {
  if (str == NULL) {
    EvrMyCo_SendNoData ();                         // Record Event
    return;
  }
  if (MyComp_data.is_free == 1) {
    uint32_t str_size;
    str_size=strlen(str);
    strncpy(MyComp_data.buf, str, sizeof(MyComp_data.buf));
    MyComp_data.is_free = 0;
    EvrMyCo_SendComplete(str_size);                // Record Event
  } else {
    EvrMyCo_SendFailed();                          // Record Event
  }
}

// Receive message from buffer
void MyComp_receive (char* str) {
  if (str == NULL) {
    EvrMyCo_ReceiveNoData ();                      // Record Event
    return;
  }
  if (MyComp_data.is_free == 0) {
    uint32_t str_size;
    strncpy(str, MyComp_data.buf, sizeof(MyComp_data.buf));
    str_size=strlen(str);
    MyComp_data.is_free = 1;
    EvrMyCo_ReceiveComplete(str_size);             // Record Event
  } else {
    EvrMyCo_ReceiveFailed();                       // Record Event
  }
}

